@@ -1,7 +1,7 @@
 #' BP_pred_SAR
 #' to be documented
 #' @usage BP_pred_SAR(YS,X,W,e,beta_hat,lambda_hat,S,O,type='BPN',
-#' model='SAR',W_extra=NULL,k_extra=30,kernel_extra='sheppard',coords=NULL,maxobs=4000)
+#' model='SAR',W_extra=NULL,k_extra=30,kernel_extra='shepard',coords=NULL,maxobs=4000)
 #' @param YS to be documented
 #' @param X to be documented
 #' @param W to be documented
@@ -19,7 +19,7 @@
 #' @param maxobs to be documented
 #' @noRd
 #' @return to be documented
-BP_pred_SAR<-function (YS, X, W, e, beta_hat, lambda_hat, S, O, type = "BPN",model = "SAR", W_extra = NULL, k_extra = 30, kernel_extra = "sheppard", coords = NULL,maxobs=4000){
+BP_pred_SAR<-function (YS, X, W, e, beta_hat, lambda_hat, S, O, type = "BPN",model = "SAR", W_extra = NULL, k_extra = 30, kernel_extra = "shepard", coords = NULL,maxobs=4000){
   warnings('YS  and e should have S rows, X should be the matrix of new_data with S+O rows (order S then O), W should be a row normalized matrix of dim (S+0,S+O)')
   n=length(c(S,O))
   if(n!=nrow(X)) stop('Wrong arguments: S should be the row index of in-sample and O the row index of out-sample, ex. S=1:100,O=101:120 ')
