@@ -6,6 +6,6 @@
 #' @return to be documented
 aic_model <-
 function(model){
-  n=length(model$Y)
-log(model$SSR) + 2*(ifelse(is.null(model$tS),model$edf,model$tS))/n
+  n=length(model@Y)
+log(model@SSR) + 2*(ifelse(is.null(model@tS),model@edf,model@tS))/n
 }
