@@ -1,15 +1,15 @@
 #' equidistantGrid
 #' to be documented
-#' @usage equidistantGrid(nTP,coord)
+#' @usage equidistantGrid(nTP,coords)
 #' @param nTP to be documented
-#' @param coord to be documented
+#' @param coords to be documented
 #' @noRd
 #' @return to be documented
-equidistantGrid<-function(nTP,coord){
-  xmin=min(coord[,1])
-  xmax=max(coord[,1])
-  ymin=min(coord[,2])
-  ymax=max(coord[,2])
+equidistantGrid<-function(nTP,coords){
+  xmin=min(coords[,1])
+  xmax=max(coords[,1])
+  ymin=min(coords[,2])
+  ymax=max(coords[,2])
   rx=xmax-xmin
   ry=ymax-ymin
   surface=(rx*ry)
@@ -21,7 +21,7 @@ equidistantGrid<-function(nTP,coord){
   coordg=expand.grid(xx,yy)
   colnames(coordg)=c('x','y')
   #coordg<-coordg[sort(sample(1:nrow(coordg),nTP)),]
-  index<-unique((knn(coord,coordg,1))$nn.idx)
+  index<-unique((knn(coords,coordg,1))$nn.idx)
   #if(length(index)>nTP) index <- index[sample(1:length(index),nTP)]
   sort(index)
 }
