@@ -1,6 +1,7 @@
 #' fill_DGPTAB
 #' to be documented
-#' @usage fill_DGPTAB(formula,data,coords,fixed_vars,Model,control,opt,search_W,config_model)
+#' @usage fill_DGPTAB(formula,data,coords,fixed_vars,Model,control,opt,
+#' search_W,config_model)
 #' @param formula  to be documented
 #' @param data  to be documented
 #' @param coords  to be documented
@@ -15,6 +16,6 @@
 fill_DGPTAB <-function(formula,data,coords,fixed_vars,Model,control,opt,search_W,config_model){
   est_model=model_conf(formula,data,coords,fixed_vars,Model,control,config_model,search_W)
   if(!(Model %in% c('OLS','SAR'))){
-    list(config_model=config_model,CV=opt$objective,SSR=est_model$SSR,model=est_model,dists=control$dists,indexG=control$indexG)
-  } else {list(config_model=config_model,CV=0,SSR=est_model$SSR,model=est_model)}
+    list(config_model=config_model,CV=opt$objective,SSR=est_model@SSR,model=est_model,dists=control$dists,indexG=control$indexG)
+  } else {list(config_model=config_model,CV=0,SSR=est_model@SSR,model=est_model)}
 }
